==> wpewebkit_2.28.1.orig.tar.xz: wpewebkit-2.28.1/Source/ThirdParty/ANGLE/src/libANGLE/validationGL46.cpp <==
//
// Copyright 2019 The ANGLE Project Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
//

// validationGL46.cpp: Validation functions for OpenGL 4.6 entry point parameters

#include "libANGLE/validationGL46_autogen.h"

namespace gl
{

bool ValidateMultiDrawArraysIndirectCount(Context *context,
                                          GLenum mode,
                                          const void *indirect,
                                          GLintptr drawcount,
                                          GLsizei maxdrawcount,
                                          GLsizei stride)
{
    return true;
}

bool ValidateMultiDrawElementsIndirectCount(Context *context,
                                            GLenum mode,
                                            GLenum type,
                                            const void *indirect,
                                            GLintptr drawcount,
                                            GLsizei maxdrawcount,
                                            GLsizei stride)
{
    return true;
}

bool ValidatePolygonOffsetClamp(Context *context, GLfloat factor, GLfloat units, GLfloat clamp)
{
    return true;
}

bool ValidateSpecializeShader(Context *context,
                              GLuint shader,
                              const GLchar *pEntryPoint,
                              GLuint numSpecializationConstants,
                              const GLuint *pConstantIndex,
                              const GLuint *pConstantValue)
{
    return true;
}

}  // namespace gl

==> wpewebkit_2.34.2.orig.tar.xz: wpewebkit-2.34.2/Source/ThirdParty/ANGLE/src/libANGLE/validationGL46.cpp <==
//
// Copyright 2019 The ANGLE Project Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
//

// validationGL46.cpp: Validation functions for OpenGL 4.6 entry point parameters

#include "libANGLE/validationGL46_autogen.h"

namespace gl
{

bool ValidateMultiDrawArraysIndirectCount(const Context *context,
                                          GLenum mode,
                                          const void *indirect,
                                          GLintptr drawcount,
                                          GLsizei maxdrawcount,
                                          GLsizei stride)
{
    return true;
}

bool ValidateMultiDrawElementsIndirectCount(const Context *context,
                                            GLenum mode,
                                            GLenum type,
                                            const void *indirect,
                                            GLintptr drawcount,
                                            GLsizei maxdrawcount,
                                            GLsizei stride)
{
    return true;
}

bool ValidatePolygonOffsetClamp(const Context *context,
                                GLfloat factor,
                                GLfloat units,
                                GLfloat clamp)
{
    return true;
}

bool ValidateSpecializeShader(const Context *context,
                              GLuint shader,
                              const GLchar *pEntryPoint,
                              GLuint numSpecializationConstants,
                              const GLuint *pConstantIndex,
                              const GLuint *pConstantValue)
{
    return true;
}

}  // namespace gl
